var WebSocketServer = require("websocket").server;
var http = require("http");

const { MongoClient, ServerApiVersion } = require("mongodb");
require("dotenv").config();

// Setup database information
const client = new MongoClient(process.env.DATABASE_URI, {
   useNewUrlParser: true,
   useUnifiedTopology: true,
   serverApi: ServerApiVersion.v1,
});

var server = http.createServer(function (request, response) {
   console.log(new Date() + " Received request for " + request.url);
   response.writeHead(404);
});
server.listen(process.env.PORT, function () {
   console.log(new Date() + ` Server is listening on port ${process.env.PORT}`);
});
wsServer = new WebSocketServer({
   httpServer: server,
   // You should not use autoAcceptConnections for production
   // applications, as it defeats all standard cross-origin protection
   // facilities built into the protocol and the browser.  You should
   // *always* verify the connection's origin and decide whether or not
   // to accept it.
   autoAcceptConnections: false,
});

function originIsAllowed(origin) {
   // put logic here to detect whether the specified origin is allowed.
   return true;
}

wsServer.on("request", function (request) {
   //console.log(request)
   if (!originIsAllowed(request.origin)) {
      // Make sure we only accept requests from an allowed origin
      request.reject();
      console.log(
         new Date() + " Connection from origin " + request.origin + " rejected."
      );
      return;
   }

   var connection = request.accept(null, request.origin);
   console.log(new Date() + " Connection accepted.");

   connection.on("message", async function (message) {
      if (message.type === "utf8") {
         console.log("Received Message: " + message.utf8Data);
         const receivedData = JSON.parse(message.utf8Data);

         try {
            await client.connect();
            const database = client.db(process.env.DATABASE_NAME);
            const collection = database.collection(
               process.env.DATABASE_COLLECTION
            );
            console.log("Database connected");

            const docCount = await collection.countDocuments({});
            console.log(docCount);

            const data = {
               id: docCount,
               device: receivedData.client,
               room1: receivedData.room1,
               room2: receivedData.room2,
               room3: receivedData.room3,
               timestamp: Date.now(),
            };

            console.log(data);
            await collection.insertOne(data);

            // perform actions using client
         } finally {
            // Ensures that the client will close when you finish/error
            await client.close();
         }
      } else if (message.type === "binary") {
         console.log(
            "Received Binary Message of " + message.binaryData.length + " bytes"
         );
         // connection.sendBytes(message.binaryData);
      }
   });

   connection.on("close", function (reasonCode, description) {
      console.log(
         new Date() + " Peer " + connection.remoteAddress + " disconnected."
      );
   });
});
