#include <WiFi.h>
#include <HTTPClient.h>
#include <ArduinoJson.h>
#include <Wire.h>
#include <Adafruit_SSD1306.h>

#define SCREEN_WIDTH 128
#define SCREEN_HEIGHT 32

Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, -1);

// const char* ssid = "Mild";
// const char* password = "00000000";
const char* ssid = "Kittipong";
const char* password = "12345678";
// const char* ssid = "Genius_network 2.4GHz";
// const char* password = "1212312121";

// const char* host = "http://192.168.1.103:5050";
// const char* host = "http://172.20.10.7:5050";
const char* host = "http://172.20.10.3:5050";
const char* endpoint = "/sync/short-info";

String on_off(bool status) {
  if(status) return "ON ";
  return "OFF";
}

void setup() {
  Serial.begin(115200);
  delay(10);

  Serial.print("Connecting to ");
  Serial.println(ssid);

  WiFi.begin(ssid, password);

  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }

  Serial.println("");
  Serial.println("WiFi connected");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());


  if (!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) {
    Serial.println(F("SSD1306 allocation failed"));
    for (;;)
      ;
  }

  display.clearDisplay();
  display.setTextSize(1);
  display.setTextColor(WHITE);
}

void loop() {
  if (WiFi.status() == WL_CONNECTED) {  // Check if connected to Wi-Fi
    HTTPClient http;
    String apiUrl = String(host) + String(endpoint);
    http.begin(apiUrl);         // Specify the API URL
    int httpCode = http.GET();  // Send the HTTP GET request

    if (httpCode > 0) {
      String payload = http.getString();  // Get the HTTP response payload
      Serial.println("API response:");
      Serial.println(payload);

      // Parse the JSON payload
      StaticJsonDocument<256> doc;
      deserializeJson(doc, payload);

    //   return {
    //   smokeLevel: smoke.smokeLevel,
    //   temperature: temperature.temperature,
    //   room1: light.room1,
    //   room2: light.room2,
    //   room3: light.room3,
    //   curtain: curtain.curtain
    // }

      int smokeLevel = doc["smokeLevel"];
      int temperature = doc["temperature"];
      bool room1 = doc["room1"];
      bool room2 = doc["room2"];
      bool room3 = doc["room3"];
      bool curtain = doc["curtain"];

      display.setCursor(0, 0);
      // line 1
      display.print("R1:");
      display.print(on_off(room1));
      display.print(" ");
      display.print("R2:");
      display.print(on_off(room2));
      display.print(" ");
      display.print("R3:");
      display.println(on_off(room3));

      // line 2
      display.print("Smoke lvl.:");
      display.println(smokeLevel);

      // line 3
      display.print("Temperature:");
      display.print(temperature);
      display.write(167); // Unicode for degree symbol
      display.println("C");

      // line 4
      display.print("Curtain:");
      display.println(on_off(curtain));

      display.display();

    } else {
      Serial.print("Error on HTTP request: ");
      Serial.println(httpCode);
    }

    http.end();  // Close the connection
  } else {
    Serial.println("Error in WiFi connection");
  }

  delay(1000);  // Wait for 60 seconds before making another request
}
