#include <WiFi.h>
#include <Wire.h>
#include <WebSocketClient.h>
#include <Arduino.h>
#include <ArduinoJson.h>
#include <HTTPClient.h>
#include <SPI.h>
#include <DHT.h>   
#include <WiFi.h>


#define CLIENT "Device-01"
#define TYPE "ESP32"
#define DHTPIN 15 
#define DHTTYPE DHT22  
#define MotorPin2 0  

const char* ssid = "Kittipong";
const char* password = "12345678";
char path[] = "/";

char host[] = "172.20.10.6:4000"; 
char ipv4[] = "172.20.10.6"; 

RTC_DATA_ATTR int Count = 0;
RTC_DATA_ATTR int timeCount = 0; 
RTC_DATA_ATTR char name[15] = CLIENT;
StaticJsonDocument<500> doc;

DHT dht(DHTPIN, DHTTYPE);  
const int pwmPin = 0;
const int pwmChannel = 0;
const int freq = 5000;
const int resolution = 8;

WebSocketClient webSocketClient;

// Use WiFiClient class to create TCP connections
WiFiClient client;

String data;

void initWiFi() {
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);
  Serial.print("Connecting to WiFi ...");
  while (WiFi.status() != WL_CONNECTED) {
    Serial.print('.');
    delay(1000);
  }
  Serial.println(WiFi.localIP());
}

void setup(void)
{
  doc["client"] = CLIENT;
  pinMode(MotorPin2,OUTPUT);
  Serial.begin(9600);  
  dht.begin(); 
  ledcSetup(pwmChannel, freq, resolution);
  ledcAttachPin(pwmPin, pwmChannel);

  initWiFi();
  Serial.print("RRSI: ");
  Serial.println(WiFi.RSSI());
}

void POSTData()
{  
  if (WiFi.status() == WL_CONNECTED){
    Serial.print("mine");
    if (client.connect(ipv4, 4000)) {
      Serial.println("Connected");
    }
    webSocketClient.path = path;
    webSocketClient.host = host;
    if (webSocketClient.handshake(client)) {
      Serial.println("Data sent successfully");

      String json;
      serializeJson(doc, json);
      webSocketClient.sendData(json);
      
    }
  }
}

void loop(void)
{ 
  ledcWrite(pwmChannel, 0);
  delay(1000);
  float level;
  float temperature = dht.readTemperature();  
  float humidity = dht.readHumidity(); 
  if (temperature < 20) {
    level = 255;
  }
  else if (temperature < 40) {
    level = 255 - ((temperature - 20)/20 * 255);
  }
  else {
    level = 0;
  }
  int speed = (100 - level*(100/255))+1 ;
 
  ledcWrite(pwmChannel, 127);
  delay(1000/speed);
  ledcWrite(pwmChannel, 0);
  delay(5000);
 
  // Print the data to the serial monitor
  speed = 100 - (level/255)*100 ;
  Serial.print("Temperature: ");
  Serial.print(temperature);
  Serial.print(" °C, Humidity: ");
  Serial.print(humidity);
  Serial.println("%");
  Serial.println(speed);
  Serial.println(level);
  if (timeCount % 20 == 0){
    Count++;
    doc["count"] = Count;
    doc["temperature"] = temperature;
    doc["speed"] = speed; 
    
    timeCount = 0;
    POSTData();
    // serializeJsonPretty(doc, Serial);
  }
  timeCount++;
  delay(500);

  
}

